@@ -1,6 +1,7 @@
 # Copyright Nova Code (http://www.novacode.nl)
 # See LICENSE file for full licensing details.
 
+import calendar
 import json
 import uuid
 
@@ -141,7 +142,7 @@ class Component:
         return self.component_owner
 
     @property
-    def valdidate(self):
+    def validate(self):
         return self.raw.get('validate')
 
     @property
@@ -370,14 +371,14 @@ class datetimeComponent(Component):
         Dictionary of mappings between Formio Datetime component
         (key) to Python format (value).
 
-        Formio uses the format codes refererend in:
+        Formio uses the format codes referenced in:
         https://github.com/angular-ui/bootstrap/tree/master/src/dateparser/docs#uibdateparsers-format-codes
         """
         return {
             'year': {'yyyy': '%Y', 'yy': '%y', 'y': '%y'},
             'month': {'MMMM': '%B', 'MMM': '%b', 'MM': '%m', 'M': '%-m'},
             'day': {'dd': '%d', 'd': '%-d'},
-            'hour': {'HH': '%HH', 'H': '%-H', 'hh': '%I', 'h': '%-I'},
+            'hour': {'HH': '%H', 'H': '%-H', 'hh': '%I', 'h': '%-I'},
             'minute': {'mm': '%M', 'm': '%-M'},
             'second': {'ss': '%S', 's': '%-S'},
             'am_pm': {'a': '%p'}
@@ -490,7 +491,10 @@ class datetimeComponent(Component):
 
 
 class dayComponent(Component):
-    pass
+
+    @property
+    def dayFirst(self):
+        return self.raw.get('dayFirst')
 
     @property
     def value(self):
@@ -498,35 +502,49 @@ class dayComponent(Component):
 
     @value.setter
     def value(self, value):
+        """
+        Notes:
+        - value format: dd/dd/yyyy
+        - Empty value: '00/00/0000'
+        """
         val = OrderedDict()
         fields = self.raw['fields']
 
-        date_parts = []
-        date_format = []
-        date_format_index = {}
-
-        if not fields['month'].get('hide'):
-            date_parts.append(value[0:2])
-            date_format.append('%m')
-            date_format_index[self.component_owner.date_format.index('%m')] = 'month'
-
-        if not fields['day'].get('hide'):
-            date_parts.append(value[3:5])
-            date_format.append('%d')
-            date_format_index[self.component_owner.date_format.index('%d')] = 'day'
+        # XXX Maybe future formio versions have more formatting possibilites.
+        if self.dayFirst:
+            if not fields['day'].get('hide'):
+                day_val = value[0:2]
+                if day_val != '00':
+                    val['day'] = int(day_val)
+                else:
+                    val['day'] = None
+            if not fields['month'].get('hide'):
+                month_val = value[3:5]
+                if month_val != '00':
+                    val['month'] = int(month_val)
+                else:
+                    val['month'] = None
+        else:
+            if not fields['month'].get('hide'):
+                month_val = value[0:2]
+                if month_val != '00':
+                    val['month'] = int(month_val)
+                else:
+                    val['month'] = None
+            if not fields['day'].get('hide'):
+                day_val = value[3:5]
+                if day_val != '00':
+                    val['day'] = int(day_val)
+                else:
+                    val['day'] = None
 
         if not fields['year'].get('hide'):
-            date_parts.append(value[6:10])
-            date_format.append('%Y')
-            date_format_index[self.component_owner.date_format.index('%Y')] = 'year'
-
-        date_str = '/'.join(date_parts)
-        date_format = '/'.join(date_format)
-        dt_obj = datetime.strptime(date_str, date_format)
-
-        for key in sorted(date_format_index):
-            part = date_format_index[key]
-            val[part] = getattr(dt_obj, part)
+            if not fields['year'].get('hide'):
+                year_val = value[6:10]
+                if year_val != '0000':
+                    val['year'] = int(year_val)
+                else:
+                    val['year'] = None
 
         super(self.__class__, self.__class__).value.fset(self, val)
 
@@ -534,7 +552,7 @@ class dayComponent(Component):
     def day(self):
         fields = self.raw['fields']
         if not fields['day'].get('hide'):
-            return self.raw_value[0:2]
+            return self.value['day']
         else:
             return None
 
@@ -542,7 +560,19 @@ class dayComponent(Component):
     def month(self):
         fields = self.raw['fields']
         if not fields['month'].get('hide'):
-            return self.raw_value[3:5]
+            return self.value['month']
+        else:
+            return None
+
+    @property
+    def month_name(self):
+        fields = self.raw['fields']
+        if self.value['month'] and not fields['month'].get('hide'):
+            month_name = calendar.month_name[self.value['month']]
+            if self.i18n.get(self.language):
+                return self.i18n[self.language].get(month_name, month_name)
+            else:
+                return month_name
         else:
             return None
 
@@ -550,7 +580,7 @@ class dayComponent(Component):
     def year(self):
         fields = self.raw['fields']
         if not fields['year'].get('hide'):
-            return self.raw_value[6:10]
+            return self.value['year']
         else:
             return None
 
